@@ -1,6 +1,5 @@
 from typing import Dict, Optional, Union, cast
 
-import stripe  # noqa
 from stripe._error_object import ErrorObject
 
 
@@ -26,14 +25,20 @@ class StripeError(Exception):
         super(StripeError, self).__init__(message)
 
         body: Optional[str] = None
-        if http_body and hasattr(http_body, "decode"):
-            try:
-                body = cast(bytes, http_body).decode("utf-8")
-            except BaseException:
-                body = (
-                    "<Could not decode body as utf-8. "
-                    "Please report to support@stripe.com>"
-                )
+        if http_body:
+            # http_body can sometimes be a memoryview which must be cast
+            # to a "bytes" before calling decode, so we check for the
+            # decode attribute and then cast
+            if hasattr(http_body, "decode"):
+                try:
+                    body = cast(bytes, http_body).decode("utf-8")
+                except BaseException:
+                    body = (
+                        "<Could not decode body as utf-8. "
+                        "Please report to support@stripe.com>"
+                    )
+            elif isinstance(http_body, str):
+                body = http_body
 
         self._message = message
         self.http_body = body
@@ -76,10 +81,11 @@ class StripeError(Exception):
         ):
             return None
         from stripe._error_object import ErrorObject
+        from stripe._api_requestor import _APIRequestor
 
         return ErrorObject._construct_from(
             values=self.json_body["error"],
-            requestor=stripe._APIRequestor._global_instance(),
+            requestor=_APIRequestor._global_instance(),
             # We pass in API mode as "V1" here because it's required,
             # but ErrorObject is reused for both V1 and V2 errors.
             api_mode="V1",
